from viavi.evm import *
from viavi.diag import DIAG


@DIAG("Return Bist version")
def t_bist_version(cmd):
    with open("/etc/bist.conf", "r") as f:
        version = f.read()
        print_info("# VERSION: %s"%version.strip())
    return None
